# PhyloX

PhyloX is a python package with tools for constructing, manipulating, and analyzing phylogenetic networks.

## Install

Install as pypi package phylox:
```
pip install phylox
```

## Usage

You can load the package methods with `import phylox` in python.
